mafw.db.db\_model
=================

.. automodule:: mafw.db.db_model

   
   .. rubric:: Module Attributes

   .. autosummary::
   
      database_proxy
   
   .. rubric:: Classes

   .. autosummary::
   
      MAFwBaseModel
   
   .. rubric:: Exceptions

   .. autosummary::
   
      MAFwBaseModelDoesNotExist
   